require "spec_helper"

describe Brew do
  let(:brew) { Brew.new(Leap::CLI.new, {}, 'project') }

  describe '#eligible?' do
    it 'returns true for mac os' do
      RbConfig::CONFIG['host_os'] = 'mac os'
      expect(brew).to be_eligible
    end

    it 'returns true for darwin' do
      RbConfig::CONFIG['host_os'] = 'darwin'
      expect(brew).to be_eligible
    end

    it 'returns false for anything else' do
      RbConfig::CONFIG['host_os'] = 'mswin'
      expect(brew).to_not be_eligible
    end
  end

  describe '#install' do
    it 'notifies user' do
      expect_any_instance_of(Leap::CLI)
        .to receive('say')
        .exactly(:once)
        .with('Installing brew', :green)

      allow_any_instance_of(Object).to receive(:exec).and_return(double)

      brew.install
    end

    it 'installs brew' do
      expect_any_instance_of(Object)
        .to receive(:exec)
        .with('ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"')
        .exactly(:once)

      brew.install
    end
  end

  describe '#install_dependencies' do
    before do
      allow_any_instance_of(Object).to receive(:exec).and_return(double)
    end

    context 'when no dependencies are present' do
      it 'alerts user' do
        brew = Brew.new(Leap::CLI.new, {}, 'project')

        expect_any_instance_of(Leap::CLI)
          .to receive('say')
          .exactly(:once)
          .with('No dependencies found in leap config', :red)

        brew.install_dependencies
      end
    end

    context 'when dependencies are present' do
      context 'when local_package is not present' do
        before { allow_any_instance_of(Object).to receive(:`).and_return('') }

        it 'notifies user for every dependency' do
          brew = Brew.new(Leap::CLI.new, { 'dependencies' => ['redis', 'awk'] }, 'project')

          expect_any_instance_of(Leap::CLI)
            .to receive('say')
            .exactly(:twice)

          brew.install_dependencies
        end

        it 'installs dependencies via brew' do
          brew = Brew.new(Leap::CLI.new, { 'dependencies' => ['redis'] }, 'project')

          expect_any_instance_of(Object)
            .to receive(:exec)
            .with("brew install redis")

          brew.install_dependencies
        end
      end
    end
  end

  describe '#present?' do
    it 'returns false if brew executable is not found' do
      allow_any_instance_of(Object)
        .to receive(:find_executable)
        .with('brew')
        .and_return(nil)

      expect(brew).to_not be_present
    end

    it 'returns true if brew executable is found' do
      allow_any_instance_of(Object)
        .to receive(:find_executable)
        .with('brew')
        .and_return('/usr/local/bin/brew')

      expect(brew).to be_present
    end
  end
end
