require "spec_helper"

describe Remotes do

  describe '#add_specified_remotes' do
    context 'when no remotes are present' do
      let(:remotes) { Remotes.new(Leap::CLI.new, {}) }

      it 'alerts the user' do
        expect{
          remotes.add_specified_remotes
        }.to output("No remotes specified\n").to_stdout
      end

      it 'does not add remotes' do
        expect(remotes).to_not receive(:add_remote)

        remotes.add_specified_remotes
      end
    end

    context 'when remotes are present' do
      let(:remotes) do
        Remotes.new(
          Leap::CLI.new,
          { "remotes" => {
              "origin" => 'git@github.com:generalassembly/leap.git'
            }
          }
        )
      end

      it 'adds remotes' do
        expect(remotes).to receive(:add_remote).exactly(:once)

        remotes.add_specified_remotes
      end
    end
  end

  describe '#add_remote' do
    let(:remotes) do
      Remotes.new(
        Leap::CLI.new,
        { "remotes" => {
            "origin" => 'git@github.com:generalassembly/leap.git'
          }
        },
        'project'
      )
    end

    it 'notifies user' do
      expect_any_instance_of(Leap::CLI)
        .to receive('say')
        .exactly(:once)
        .with('Adding origin remote')

      remotes.add_remote(remotes.remotes.keys.first, remotes.remotes.values.first)
    end

    context 'when project name is present' do
      it 'cds into project and adds remote' do
        expect(remotes)
          .to receive(:`)
          .exactly(:once)
          .with("cd project && git remote add origin git@github.com:generalassembly/leap.git")

        remotes.add_remote(remotes.remotes.keys.first, remotes.remotes.values.first, "project")
      end
    end

    context 'when project name is not present' do
      it 'does not cd into project, then adds remote' do
        expect(remotes)
          .to receive(:`)
          .exactly(:once)
          .with("git remote add origin git@github.com:generalassembly/leap.git")

        remotes.add_remote(remotes.remotes.keys.first, remotes.remotes.values.first, nil)
      end
    end
  end
end
